@@ -5,7 +5,7 @@ Tests for slack_client module.
 import pytest
 from unittest.mock import patch, Mock, MagicMock
 from slack_sdk.errors import SlackApiError
-from nui_lambda_shared_utils.slack_client import SlackClient, ACCOUNT_NAMES
+from nui_lambda_shared_utils.slack_client import SlackClient, DEFAULT_ACCOUNT_NAMES
 import os
 from datetime import datetime
 
@@ -13,7 +13,7 @@ from datetime import datetime
 class TestSlackClient:
     """Tests for SlackClient class."""
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_init_required_secret(self, mock_webclient, mock_get_secret):
         """Test initialization requires secret name parameter."""
@@ -24,7 +24,7 @@ class TestSlackClient:
         mock_get_secret.assert_called_once_with("test-secret")
         mock_webclient.assert_called_once_with(token="xoxb-test-token")
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_init_custom_secret(self, mock_webclient, mock_get_secret):
         """Test initialization with custom secret name."""
@@ -35,16 +35,26 @@ class TestSlackClient:
         mock_get_secret.assert_called_once_with("custom-slack-secret")
         mock_webclient.assert_called_once_with(token="xoxb-custom-token")
 
-    def test_init_requires_secret_name(self):
-        """Test that initialization requires secret_name parameter."""
-        with pytest.raises(TypeError, match="missing 1 required positional argument: 'secret_name'"):
-            SlackClient()
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict("os.environ", {}, clear=True)
+    def test_init_with_default_secret_name(self, mock_webclient, mock_get_secret):
+        """Test initialization with default secret name."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-default-token"}
+        
+        with patch("nui_lambda_shared_utils.base_client.resolve_config_value") as mock_resolve:
+            mock_resolve.return_value = "slack-credentials"
+            
+            client = SlackClient()
+        
+        mock_get_secret.assert_called_once_with("slack-credentials")
+        mock_webclient.assert_called_once_with(token="xoxb-default-token")
 
 
 class TestSendMessage:
     """Tests for send_message method."""
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_message_success(self, mock_webclient, mock_get_secret):
         """Test successful message sending."""
@@ -59,7 +69,7 @@ class TestSendMessage:
         assert result is True
         mock_client.chat_postMessage.assert_called_once_with(channel="C123", text="Test message", blocks=None)
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_message_with_blocks(self, mock_webclient, mock_get_secret):
         """Test sending message with blocks."""
@@ -76,7 +86,7 @@ class TestSendMessage:
         assert result is True
         mock_client.chat_postMessage.assert_called_once_with(channel="C123", text="Fallback text", blocks=blocks)
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_message_api_error(self, mock_webclient, mock_get_secret):
         """Test handling of Slack API error."""
@@ -92,7 +102,7 @@ class TestSendMessage:
 
         assert result is False
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_message_not_ok(self, mock_webclient, mock_get_secret):
         """Test handling of not ok response."""
@@ -106,7 +116,7 @@ class TestSendMessage:
 
         assert result is False
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_message_unexpected_error(self, mock_webclient, mock_get_secret):
         """Test handling of unexpected errors."""
@@ -124,7 +134,7 @@ class TestSendMessage:
 class TestSendFile:
     """Tests for send_file method."""
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_file_success(self, mock_webclient, mock_get_secret):
         """Test successful file upload."""
@@ -141,7 +151,7 @@ class TestSendFile:
             channel="C123", content="File content", filename="test.txt", title="Test File"
         )
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_file_default_title(self, mock_webclient, mock_get_secret):
         """Test file upload with default title."""
@@ -158,7 +168,7 @@ class TestSendFile:
             channel="C123", content="File content", filename="report.csv", title="report.csv"
         )
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_file_api_error(self, mock_webclient, mock_get_secret):
         """Test handling of file upload API error."""
@@ -178,7 +188,7 @@ class TestSendFile:
 class TestSendThreadReply:
     """Tests for send_thread_reply method."""
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_thread_reply_success(self, mock_webclient, mock_get_secret):
         """Test successful thread reply."""
@@ -195,7 +205,7 @@ class TestSendThreadReply:
             channel="C123", thread_ts="1234567890.123456", text="Reply text", blocks=None
         )
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_send_thread_reply_with_blocks(self, mock_webclient, mock_get_secret):
         """Test thread reply with blocks."""
@@ -218,7 +228,7 @@ class TestSendThreadReply:
 class TestUpdateMessage:
     """Tests for update_message method."""
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_update_message_success(self, mock_webclient, mock_get_secret):
         """Test successful message update."""
@@ -235,7 +245,7 @@ class TestUpdateMessage:
             channel="C123", ts="1234567890.123456", text="Updated text", blocks=None
         )
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_update_message_api_error(self, mock_webclient, mock_get_secret):
         """Test handling of update API error."""
@@ -255,7 +265,7 @@ class TestUpdateMessage:
 class TestAddReaction:
     """Tests for add_reaction method."""
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_add_reaction_success(self, mock_webclient, mock_get_secret):
         """Test successful reaction addition."""
@@ -272,7 +282,7 @@ class TestAddReaction:
             channel="C123", timestamp="1234567890.123456", name="thumbsup"
         )
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_add_reaction_already_exists(self, mock_webclient, mock_get_secret):
         """Test handling when reaction already exists."""
@@ -288,7 +298,7 @@ class TestAddReaction:
 
         assert result is True  # Should return True for already_reacted
 
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     def test_add_reaction_api_error(self, mock_webclient, mock_get_secret):
         """Test handling of reaction API error."""
@@ -308,8 +318,24 @@ class TestAddReaction:
 class TestLambdaContextHeader:
     """Tests for Lambda context header functionality."""
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @staticmethod
+    def assert_header_format(header_text: str, expected_parts: dict):
+        """
+        Helper to assert header format with nice error messages.
+
+        Args:
+            header_text: Full header text from Slack block
+            expected_parts: Dict of expected values to check
+
+        Shows the full header on assertion failure for easy debugging.
+        """
+        failure_msg = f"\n\nFull header text:\n{header_text}\n\nExpected to contain: {expected_parts}\n"
+
+        for key, value in expected_parts.items():
+            assert value in header_text, f"{failure_msg}Missing {key}: {value}"
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(
         os.environ,
@@ -333,7 +359,7 @@ class TestLambdaContextHeader:
 
         # Mock STS for account info
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {
             "Account": "123456789012",  # Production
             "Arn": "arn:aws:sts::123456789012:assumed-role/test-role/test-function",
@@ -341,7 +367,7 @@ class TestLambdaContextHeader:
 
         # Mock Lambda client for deployment time
         mock_lambda = Mock()
-        mock_boto3.client.side_effect = lambda service: mock_sts if service == "sts" else mock_lambda
+        mock_boto3.side_effect = lambda service: mock_sts if service == "sts" else mock_lambda
         mock_lambda.get_function.return_value = {"Configuration": {"LastModified": "2023-11-15T10:30:45.123+0000"}}
 
         # Mock config file check
@@ -363,24 +389,20 @@ class TestLambdaContextHeader:
             assert header_block["type"] == "context"
             header_text = header_block["elements"][0]["text"]
 
-            # Check line 1 content - no stage shown for prod in prod
-            assert "🤖" in header_text  # AI robot emoji
-            assert "`test-function`" in header_text
-            assert "(prod)" not in header_text  # Stage not shown when it matches environment
+            # Use helper to check all expected parts
+            self.assert_header_format(header_text, {
+                "robot emoji": "🤖",
+                "function name": "test-function",
+                "location emoji": "📍",
+                "account name": "Production",
+                "account ID": "(123456789012)",
+                "region": "eu-west-1",
+                "log emoji": "📋",
+                "log group": "`/aws/lambda/test-function`"
+            })
 
-            # Check line 2 content
-            assert "📍" in header_text  # Location emoji
-            assert "Production" in header_text  # Simplified account name
-            assert "eu-west-1" in header_text
-            assert "Deployed:" in header_text
-
-            # Check line 3 content
-            assert "📋" in header_text  # Log emoji
-            assert "Log:" in header_text
-            assert "`/aws/lambda/test-function`" in header_text
-
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(
         os.environ,
@@ -400,7 +422,7 @@ class TestLambdaContextHeader:
 
         # Mock STS for account info
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {
             "Account": "234567890123",  # Development
             "Arn": "arn:aws:sts::234567890123:assumed-role/test-role/nui-service",
@@ -408,7 +430,7 @@ class TestLambdaContextHeader:
 
         # Mock Lambda client - deployment time fails
         mock_lambda = Mock()
-        mock_boto3.client.side_effect = lambda service: mock_sts if service == "sts" else mock_lambda
+        mock_boto3.side_effect = lambda service: mock_sts if service == "sts" else mock_lambda
         mock_lambda.get_function.side_effect = Exception("Access denied")
 
         # Mock config file check
@@ -429,17 +451,19 @@ class TestLambdaContextHeader:
             assert header_block["type"] == "context"
             header_text = header_block["elements"][0]["text"]
 
-            # Check emojis and content - no stage shown for dev in dev
-            assert "🤖" in header_text  # AI robot emoji
-            assert "`nui-service`" in header_text
-            assert "(dev)" not in header_text  # Stage not shown when it matches environment
-            assert "Development" in header_text  # Simplified account name
-            assert "ap-southeast-2" in header_text
-            assert "Unknown" in header_text  # Deploy time unknown due to error
-            assert "📋" in header_text  # Log emoji
+            # Use helper to check all expected parts
+            self.assert_header_format(header_text, {
+                "robot emoji": "🤖",
+                "function name": "nui-service",
+                "location emoji": "📍",
+                "account name": "Development",
+                "account ID": "(234567890123)",
+                "region": "ap-southeast-2",
+                "log emoji": "📋"
+            })
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(os.environ, {})  # No Lambda environment variables
     def test_lambda_header_not_in_lambda(self, mock_webclient, mock_get_secret, mock_boto3):
@@ -451,7 +475,7 @@ class TestLambdaContextHeader:
 
         # Mock STS to simulate that we can't get account info when not in Lambda
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.side_effect = Exception("Not authenticated")
 
         slack = SlackClient(secret_name="test-secret")
@@ -467,8 +491,8 @@ class TestLambdaContextHeader:
         assert blocks[0]["type"] == "context"  # First block is header
         assert blocks[1]["text"]["text"] == "Original block"  # Second block is original
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function", "STAGE": "prod"})
     def test_lambda_header_can_be_disabled(self, mock_webclient, mock_get_secret, mock_boto3):
@@ -480,7 +504,7 @@ class TestLambdaContextHeader:
 
         # Mock STS
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {"Account": "123456789012"}
 
         slack = SlackClient(secret_name="test-secret")
@@ -492,8 +516,8 @@ class TestLambdaContextHeader:
 
         assert blocks is None  # No blocks added
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function", "STAGE": "prod"})
     def test_thread_reply_no_header_by_default(self, mock_webclient, mock_get_secret, mock_boto3):
@@ -505,7 +529,7 @@ class TestLambdaContextHeader:
 
         # Mock STS
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {"Account": "123456789012"}
 
         slack = SlackClient(secret_name="test-secret")
@@ -517,8 +541,8 @@ class TestLambdaContextHeader:
 
         assert blocks is None
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function", "STAGE": "prod"})
     def test_unknown_account_id_handling(self, mock_webclient, mock_get_secret, mock_boto3):
@@ -530,7 +554,7 @@ class TestLambdaContextHeader:
 
         # Mock STS with unknown account
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {
             "Account": "999999999999",  # Unknown account
             "Arn": "arn:aws:sts::999999999999:assumed-role/test-role/test-function",
@@ -547,15 +571,15 @@ class TestLambdaContextHeader:
 
         assert "Unknown (999999999999)" in header_text
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(
         os.environ,
         {"AWS_LAMBDA_FUNCTION_NAME": "dev-test-function", "STAGE": "dev", "AWS_REGION": "eu-west-1"},  # Dev stage
     )
     def test_stage_mismatch_shown_in_header(self, mock_webclient, mock_get_secret, mock_boto3):
-        """Test that stage is shown when it doesn't match the environment."""
+        """Test that header shows account name regardless of stage env var."""
         mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
         mock_client = Mock()
         mock_webclient.return_value = mock_client
@@ -563,7 +587,7 @@ class TestLambdaContextHeader:
 
         # Mock STS for Production account
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {
             "Account": "123456789012",  # Production
             "Arn": "arn:aws:sts::123456789012:assumed-role/test-role/test-function",
@@ -572,22 +596,23 @@ class TestLambdaContextHeader:
         slack = SlackClient(secret_name="test-secret")
         result = slack.send_message("C123", "Test message")
 
-        # Check header shows stage mismatch
+        # Check header shows account name only (not stage)
         call_args = mock_client.chat_postMessage.call_args
         blocks = call_args.kwargs.get("blocks", call_args[1].get("blocks"))
         header_block = blocks[0]
         header_text = header_block["elements"][0]["text"]
 
-        # Should show (dev) because it's a dev Lambda in prod account
-        assert "`dev-test-function` (dev)" in header_text
+        # Shared library doesn't interpret stage - just shows account name
+        assert "dev-test-function" in header_text
+        assert "(dev)" not in header_text  # No stage suffix
         assert "Production" in header_text
 
 
 class TestAccountNameConsistency:
     """Tests to ensure account name mappings are consistent across functions."""
 
-    @patch("nui_lambda_shared_utils.slack_client.boto3")
-    @patch("nui_lambda_shared_utils.slack_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
     @patch("nui_lambda_shared_utils.slack_client.WebClient")
     @patch.dict(os.environ, {})  # No Lambda environment variables
     def test_centralized_account_mappings(self, mock_webclient, mock_get_secret, mock_boto3):
@@ -599,7 +624,7 @@ class TestAccountNameConsistency:
 
         # Test Development ID specifically (the one that was inconsistent)
         mock_sts = Mock()
-        mock_boto3.client.return_value = mock_sts
+        mock_boto3.return_value = mock_sts
         mock_sts.get_caller_identity.return_value = {"Account": "234567890123"}  # Development
 
         slack = SlackClient(secret_name="test-secret")
@@ -617,17 +642,219 @@ class TestAccountNameConsistency:
 
         assert "Development" in header_text
 
-    def test_account_names_constant(self):
-        """Test that ACCOUNT_NAMES constant contains expected mappings."""
+    def test_default_account_names_constant(self):
+        """Test that DEFAULT_ACCOUNT_NAMES constant contains only example mappings."""
         expected_accounts = {
             "123456789012": "Production",
             "234567890123": "Development",
             "345678901234": "Staging",
         }
 
-        assert ACCOUNT_NAMES == expected_accounts
+        assert DEFAULT_ACCOUNT_NAMES == expected_accounts
 
         # Verify example account IDs are present
-        assert ACCOUNT_NAMES["123456789012"] == "Production"
-        assert ACCOUNT_NAMES["234567890123"] == "Development"
-        assert ACCOUNT_NAMES["345678901234"] == "Staging"
+        assert DEFAULT_ACCOUNT_NAMES["123456789012"] == "Production"
+        assert DEFAULT_ACCOUNT_NAMES["234567890123"] == "Development"
+        assert DEFAULT_ACCOUNT_NAMES["345678901234"] == "Staging"
+
+        # Verify no real account IDs are hardcoded
+        assert "043836023178" not in DEFAULT_ACCOUNT_NAMES
+        assert "036220212417" not in DEFAULT_ACCOUNT_NAMES
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(
+        os.environ,
+        {
+            "AWS_LAMBDA_FUNCTION_NAME": "custom-function",
+            "AWS_LAMBDA_LOG_GROUP_NAME": "/aws/lambda/custom-function",
+            "AWS_REGION": "us-east-1",
+        },
+    )
+    def test_custom_account_names_via_dict(self, mock_webclient, mock_get_secret, mock_boto3):
+        """Test that clients can provide custom account name mappings via dict."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_client = Mock()
+        mock_webclient.return_value = mock_client
+        mock_client.chat_postMessage.return_value = {"ok": True, "ts": "123"}
+
+        # Mock custom account ID
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {
+            "Account": "999888777666",
+            "Arn": "arn:aws:sts::999888777666:assumed-role/test-role/custom-function",
+        }
+
+        # Create client with custom account names
+        custom_accounts = {"999888777666": "MyCustomAccount"}
+        slack = SlackClient(secret_name="test-secret", account_names=custom_accounts)
+        result = slack.send_message("C123", "Test message")
+        assert result is True
+
+        # Verify custom account name is used
+        call_args = mock_client.chat_postMessage.call_args
+        blocks = call_args.kwargs.get("blocks", call_args[1].get("blocks"))
+        header_text = blocks[0]["elements"][0]["text"]
+
+        assert "MyCustomAccount" in header_text
+        assert "(999888777666)" in header_text
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(
+        os.environ,
+        {
+            "AWS_LAMBDA_FUNCTION_NAME": "yaml-config-function",
+            "AWS_LAMBDA_LOG_GROUP_NAME": "/aws/lambda/yaml-config-function",
+            "AWS_REGION": "eu-central-1",
+        },
+    )
+    def test_custom_account_names_via_yaml(self, mock_webclient, mock_get_secret, mock_boto3, tmp_path):
+        """Test that clients can provide custom account name mappings via YAML config."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_client = Mock()
+        mock_webclient.return_value = mock_client
+        mock_client.chat_postMessage.return_value = {"ok": True, "ts": "123"}
+
+        # Mock custom account ID
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {
+            "Account": "111222333444",
+            "Arn": "arn:aws:sts::111222333444:assumed-role/test-role/yaml-config-function",
+        }
+
+        # Create YAML config file
+        config_file = tmp_path / "slack_config.yaml"
+        config_file.write_text("""
+account_names:
+  "111222333444": "YAMLConfiguredAccount"
+  "555666777888": "AnotherAccount"
+""")
+
+        # Create client with config file
+        slack = SlackClient(secret_name="test-secret", account_names_config=str(config_file))
+        result = slack.send_message("C123", "Test message")
+        assert result is True
+
+        # Verify YAML account name is used
+        call_args = mock_client.chat_postMessage.call_args
+        blocks = call_args.kwargs.get("blocks", call_args[1].get("blocks"))
+        header_text = blocks[0]["elements"][0]["text"]
+
+        assert "YAMLConfiguredAccount" in header_text
+        assert "(111222333444)" in header_text
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function"})
+    def test_malformed_yaml_fallback_to_defaults(self, mock_webclient, mock_get_secret, mock_boto3, tmp_path):
+        """Test that malformed YAML falls back to defaults gracefully."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_webclient.return_value = Mock()
+
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {"Account": "123456789012"}
+
+        # Create malformed YAML file
+        config_file = tmp_path / "bad_config.yaml"
+        config_file.write_text("account_names: [this, is, not, a, dict]")
+
+        # Should initialize without error and use defaults
+        slack = SlackClient(secret_name="test-secret", account_names_config=str(config_file))
+
+        # Should fall back to default account name
+        assert slack._lambda_context["aws_account_name"] == "Production"  # From defaults
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function"})
+    def test_empty_yaml_file_fallback(self, mock_webclient, mock_get_secret, mock_boto3, tmp_path):
+        """Test that empty YAML file falls back to defaults."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_webclient.return_value = Mock()
+
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {"Account": "234567890123"}
+
+        # Create empty YAML file
+        config_file = tmp_path / "empty_config.yaml"
+        config_file.write_text("")
+
+        slack = SlackClient(secret_name="test-secret", account_names_config=str(config_file))
+
+        # Should use default account name
+        assert slack._lambda_context["aws_account_name"] == "Development"
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function"})
+    def test_missing_yaml_file_fallback(self, mock_webclient, mock_get_secret, mock_boto3, tmp_path):
+        """Test that missing YAML file falls back to defaults."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_webclient.return_value = Mock()
+
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {"Account": "345678901234"}
+
+        # Reference non-existent file
+        config_file = tmp_path / "nonexistent.yaml"
+
+        slack = SlackClient(secret_name="test-secret", account_names_config=str(config_file))
+
+        # Should use default account name
+        assert slack._lambda_context["aws_account_name"] == "Staging"
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function"})
+    def test_invalid_account_names_type_ignored(self, mock_webclient, mock_get_secret, mock_boto3):
+        """Test that invalid account_names parameter type is ignored gracefully."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_webclient.return_value = Mock()
+
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {"Account": "123456789012"}
+
+        # Pass invalid type (list instead of dict)
+        slack = SlackClient(secret_name="test-secret", account_names=["not", "a", "dict"])
+
+        # Should use default account name, ignoring invalid parameter
+        assert slack._lambda_context["aws_account_name"] == "Production"
+
+    @patch("nui_lambda_shared_utils.slack_client.create_aws_client")
+    @patch("nui_lambda_shared_utils.base_client.get_secret")
+    @patch("nui_lambda_shared_utils.slack_client.WebClient")
+    @patch.dict(os.environ, {"AWS_LAMBDA_FUNCTION_NAME": "test-function"})
+    def test_yaml_with_non_string_values_ignored(self, mock_webclient, mock_get_secret, mock_boto3, tmp_path):
+        """Test that YAML with non-string values is validated and ignored."""
+        mock_get_secret.return_value = {"bot_token": "xoxb-test-token"}
+        mock_webclient.return_value = Mock()
+
+        mock_sts = Mock()
+        mock_boto3.return_value = mock_sts
+        mock_sts.get_caller_identity.return_value = {"Account": "123456789012"}
+
+        # Create YAML with non-string values
+        config_file = tmp_path / "invalid_types.yaml"
+        config_file.write_text("""
+account_names:
+  "123456789012": 12345
+  "234567890123": true
+""")
+
+        slack = SlackClient(secret_name="test-secret", account_names_config=str(config_file))
+
+        # Should fall back to defaults due to type validation failure
+        assert slack._lambda_context["aws_account_name"] == "Production"
